@@ -153,6 +153,16 @@ return [
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
+		[
+			'name' => 'Chat#deleteMessage',
+			'url' => '/api/{apiVersion}/chat/{token}/{messageId}',
+			'verb' => 'DELETE',
+			'requirements' => [
+				'apiVersion' => 'v1',
+				'token' => '^[a-z0-9]{4,30}$',
+				'messageId' => '^[0-9]+$',
+			],
+		],
 		[
 			'name' => 'Chat#setReadMarker',
 			'url' => '/api/{apiVersion}/chat/{token}/read',
@@ -171,6 +181,15 @@ return [
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
+		[
+			'name' => 'Chat#shareObjectToChat',
+			'url' => '/api/{apiVersion}/chat/{token}/share',
+			'verb' => 'POST',
+			'requirements' => [
+				'apiVersion' => 'v1',
+				'token' => '^[a-z0-9]{4,30}$',
+			],
+		],
 
 		/**
 		 * Conversation (Room)
@@ -183,6 +202,14 @@ return [
 				'apiVersion' => 'v(1|2|3)',
 			],
 		],
+		[
+			'name' => 'Room#getListedRooms',
+			'url' => '/api/{apiVersion}/listed-room',
+			'verb' => 'GET',
+			'requirements' => [
+				'apiVersion' => 'v3',
+			],
+		],
 		[
 			'name' => 'Room#createRoom',
 			'url' => '/api/{apiVersion}/room',
@@ -236,6 +263,15 @@ return [
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
+		[
+			'name' => 'Room#setDescription',
+			'url' => '/api/{apiVersion}/room/{token}/description',
+			'verb' => 'PUT',
+			'requirements' => [
+				'apiVersion' => 'v3',
+				'token' => '^[a-z0-9]{4,30}$',
+			],
+		],
 		[
 			'name' => 'Room#setReadOnly',
 			'url' => '/api/{apiVersion}/room/{token}/read-only',
@@ -245,6 +281,15 @@ return [
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
+		[
+			'name' => 'Room#setListable',
+			'url' => '/api/{apiVersion}/room/{token}/listable',
+			'verb' => 'PUT',
+			'requirements' => [
+				'apiVersion' => 'v3',
+				'token' => '^[a-z0-9]{4,30}$',
+			],
+		],
 		[
 			'name' => 'Room#setPassword',
 			'url' => '/api/{apiVersion}/room/{token}/password',
@@ -317,6 +362,15 @@ return [
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
+		[
+			'name' => 'Room#resendInvitations',
+			'url' => '/api/{apiVersion}/room/{token}/participants/resend-invitations',
+			'verb' => 'POST',
+			'requirements' => [
+				'apiVersion' => 'v3',
+				'token' => '^[a-z0-9]{4,30}$',
+			],
+		],
 		[
 			'name' => 'Room#leaveRoom',
 			'url' => '/api/{apiVersion}/room/{token}/participants/active',
