@@ -264,10 +264,8 @@ OC.L10N.register(
     "STUN servers" : "STUN сървъри",
     "TURN server URL" : "URL на TURN сървъра",
     "TURN server protocols" : "Протоколи на TURN сървър",
-    "UDP and TCP" : "UDP и TCP",
-    "UDP only" : "само UDP",
-    "TCP only" : "само TCP",
     "Copy link" : "Копирай връзката",
+    "Settings" : "Настройки",
     "Dismiss" : "Отхвърляне",
     "Mute audio" : "Спиране на звука",
     "Disable video" : "Изключване на видеото",
@@ -277,12 +275,17 @@ OC.L10N.register(
     "Favorite" : "Любима",
     "Password protection" : "Password protection",
     "Enter a password" : "Въведете парола",
+    "Save" : "Запазване",
+    "Edit" : "Променяне",
+    "Password" : "Парола",
+    "Login" : "Вписване",
+    "Nickname" : "Псевдоним",
+    "Client ID" : "Client ID",
     "Remove from favorites" : "Премахни от любимите",
     "Add to favorites" : "Добави към любимите",
     "Loading" : "Зареждане",
     "Groups" : "Групи",
     "Circles" : "Обкръжения",
-    "Settings" : "Настройки",
     "Password protect" : "Защита с парола",
     "Close" : "Затваряне",
     "Camera" : "Камера",
@@ -292,12 +295,6 @@ OC.L10N.register(
     "Yesterday" : "Вчера",
     "Send message" : "Изпрати съобщение",
     "Invalid path selected" : "Предоставен е невалиден път до файл.",
-    "Enabled" : "Включено",
-    "Save" : "Запазване",
-    "Password" : "Парола",
-    "Login" : "Вписване",
-    "Nickname" : "Псевдоним",
-    "Client ID" : "Client ID",
     "guest" : "гост",
     "Remove participant" : "Премахване на участник",
     "Searching …" : "Търсене ...",
@@ -305,11 +302,11 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Participants" : "Участници",
     "Chat" : "Съобщения",
-    "Edit" : "Променяне",
     "Keyboard shortcuts" : "Бързи клавиши",
     "Search" : "Търсене",
     "Grid view" : "Решетъчен изглед",
     "Send" : "Изпрати",
+    "Error while sharing file" : "Грешка при споделяне на файл",
     "Default" : "Стандартен",
     "Access to microphone & camera is only possible with HTTPS" : "Достъпът до микрофона и камерата е възможен само при HTTPS",
     "Access to microphone & camera was denied" : "Достъпът до микрофона и камерата е отказан",
@@ -320,12 +317,10 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN сървърът се използва като прокси сървър за трафика, идващ от участници стоящи зад защитна стена.",
     "Android app" : "Android приложение",
     "iOS app" : "iOS приложениер",
-    "Contacts" : "Контакти",
-    "Guests" : "Гости",
+    "UDP and TCP" : "UDP и TCP",
+    "UDP only" : "само UDP",
+    "TCP only" : "само TCP",
     "Share link" : "Сподели връзка",
-    "Webinar" : "Уебинар",
-    "Password required" : "Паролата е задължителна",
-    "Cancel" : "Отказ",
-    "Submit" : "Изпращане"
+    "Enabled" : "Включено"
 },
 "nplurals=2; plural=(n != 1);");
