@@ -14,7 +14,6 @@ OC.L10N.register(
     "Guest" : "Invitado",
     "Talk to %s" : "Hablar con %s",
     "Join call" : "Unirse a la llamada",
-    "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
@@ -36,21 +35,19 @@ OC.L10N.register(
     "Pending" : "Pendiente",
     "Error" : "Error",
     "Blocked" : "Bloqueado",
+    "Shared secret" : "Secreto compartido",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Guardado",
-    "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
-    "UDP and TCP" : "UDP y TCP",
-    "UDP only" : "UDP únicamente",
-    "TCP only" : "TCP únicamente",
     "Copy link" : "Copiar liga",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Settings" : "Configuraciones ",
     "Dismiss" : "Descartar",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
@@ -62,29 +59,30 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Back" : "Atrás",
     "You" : "Tú",
     "Show screen" : "Mostrar pantalla",
     "Favorite" : "Hacer favorito",
-    "Remove from favorites" : "Eliminar de favoritos",
-    "Add to favorites" : "Agregar a tus favoritos",
-    "Loading" : "Cargando",
-    "Groups" : "Grupos",
-    "Circles" : "Círculos",
-    "Settings" : "Configuraciones ",
-    "Password protect" : "Proteger con contraseña",
-    "Back" : "Atrás",
-    "Close" : "Cerrar",
-    "Reply" : "Responder",
-    "Remove" : "Eliminar",
-    "Today" : "Hoy",
-    "Yesterday" : "Ayer",
-    "Enabled" : "Habilitado",
+    "Password protection" : "Protección con contraseña",
+    "Enter a password" : "Ingresa una contraseña",
     "Save" : "Guardar",
+    "Edit" : "Editar",
     "Password" : "Contraseña",
     "API token" : "Ficha del API",
     "Login" : "Iniciar sesión",
     "Nickname" : "Apodo",
     "Client ID" : "ID del cliente",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "Add to favorites" : "Agregar a tus favoritos",
+    "Loading" : "Cargando",
+    "Groups" : "Grupos",
+    "Circles" : "Círculos",
+    "Password protect" : "Proteger con contraseña",
+    "Close" : "Cerrar",
+    "Reply" : "Responder",
+    "Remove" : "Eliminar",
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
     "moderator" : "moderador",
     "Demote from moderator" : "Degradar de moderador",
     "Promote to moderator" : "Promover a moderador",
@@ -93,12 +91,8 @@ OC.L10N.register(
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
-    "Edit" : "Editar",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
-    "Share link" : "Compartir liga",
-    "Password protection" : "Protección con contraseña",
-    "Enter a password" : "Ingresa una contraseña",
     "Grid view" : "Vista de cuadrícula",
     "Send" : "Enviar",
     "Default" : "Predeterminado",
@@ -113,14 +107,11 @@ OC.L10N.register(
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "No other people in this call" : "No hay más personas en esta llamada",
-    "Your screen" : "Tu pantalla",
-    "Contacts" : "Contactos",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
-    "Guests" : "Invitados",
-    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
-    "Password required" : "Contraseña requerida",
-    "Cancel" : "Cancelar",
-    "Submit" : "Enviar"
+    "{user} wants to talk with you" : "{user} quiere hablar contigo",
+    "UDP and TCP" : "UDP y TCP",
+    "UDP only" : "UDP únicamente",
+    "TCP only" : "TCP únicamente",
+    "Share link" : "Compartir liga",
+    "Enabled" : "Habilitado"
 },
 "nplurals=2; plural=(n != 1);");
