@@ -42,15 +42,13 @@ OC.L10N.register(
     "STUN servers" : "STUN სერვერები",
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
     "TURN server protocols" : "TURN სერვერის პროტოკოლები",
-    "UDP and TCP" : "UDP და TCP",
-    "UDP only" : "მხოლოდ UDP",
-    "TCP only" : "მხოლოდ TCP",
     "Copy link" : "ბმულის კოპირება",
     "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
     "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
     "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
     "Show your screen" : "თქვენი ეკრანის ჩვენება",
     "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
+    "Settings" : "პარამეტრები",
     "Dismiss" : "დათხოვნა",
     "Mute audio" : "ხმის ჩახშობა",
     "Disable video" : "ვიდეოს გათიშვა",
@@ -68,12 +66,18 @@ OC.L10N.register(
     "Favorite" : "რჩეული",
     "Password protection" : "პაროლით თავდაცვა",
     "Enter a password" : "შეიყვანეთ პაროლი",
+    "Save" : "შენახვა",
+    "Edit" : "შეცვლა",
+    "Password" : "პაროლი",
+    "API token" : "API ტოკენი",
+    "Login" : "ავტორიზაცია",
+    "Nickname" : "ნიკნეიმი",
+    "Client ID" : "კლიენტის ID",
     "Remove from favorites" : "რჩეულებიდან ამოშლა",
     "Add to favorites" : "რჩეულებში დამატება",
     "Loading" : "იტვირთება",
     "Groups" : "ჯგუფები",
     "Circles" : "წრეები",
-    "Settings" : "პარამეტრები",
     "Password protect" : "პაროლით დაცვა",
     "Close" : "დახურვა",
     "Conversation name" : "საუბრის სახელწოდება",
@@ -82,13 +86,6 @@ OC.L10N.register(
     "Today" : "დღეს",
     "Yesterday" : "გუშინ",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Enabled" : "მოქმედია",
-    "Save" : "შენახვა",
-    "Password" : "პაროლი",
-    "API token" : "API ტოკენი",
-    "Login" : "ავტორიზაცია",
-    "Nickname" : "ნიკნეიმი",
-    "Client ID" : "კლიენტის ID",
     "moderator" : "მოდერატორი",
     "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
     "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
@@ -97,7 +94,6 @@ OC.L10N.register(
     "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
     "Participants" : "მონაწილეები",
     "Chat" : "ჩეთი",
-    "Edit" : "შეცვლა",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Search" : "ძიება",
     "Grid view" : "ბადისებური ხედი",
@@ -115,15 +111,10 @@ OC.L10N.register(
     "Android app" : "Android აპლიკაცია",
     "iOS app" : "iOS აპლიკაცია",
     "{user} wants to talk with you" : "{user} მომხმარებელს სურს თქვენთან საუბარი",
-    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
-    "Your screen" : "თქვენი ეკრანი",
-    "Contacts" : "კონტაქტები",
-    "[Unknown user name]" : "[ამოუცნობი მომხმარებელი]",
-    "Guests" : "სტუმრები",
+    "UDP and TCP" : "UDP და TCP",
+    "UDP only" : "მხოლოდ UDP",
+    "TCP only" : "მხოლოდ TCP",
     "Share link" : "ბმულის გაზიარება",
-    "Please enter the password for this call" : "შეყვანეთ პაროლი ზარისთვის",
-    "Password required" : "საჭიროა პაროლი",
-    "Cancel" : "უარყოფა",
-    "Submit" : "გაგზავნა"
+    "Enabled" : "მოქმედია"
 },
 "nplurals=2; plural=(n!=1);");
