@@ -15,6 +15,9 @@ OC.L10N.register(
     "Guest" : "Convidat",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "La benvenguda a Nextcloud Talk !\nDins aquesta conversacion vos informarem a prepaus de las foncionalitats novèlas dins Nextcloud Talk.",
     "New in Talk %s" : "Nòus dins Talk %s",
+    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge e Safari pòdon ara utilizar la conversacion àudio e vidèo",
+    "- You can now notify all participants by posting \"@all\" into the chat" : "- Podètz ara notificar totes los participants en publicant « @all » al chat",
+    "- You can now mention guests in the chat" : "- Podètz ara mencionar los convidats al chat",
     "Talk updates ✅" : "Mesas a jorn Talk ✅",
     "{actor} created the conversation" : "{actor} a creat la conversacion",
     "You created the conversation" : "Avètz creat la conversacion",
@@ -46,6 +49,9 @@ OC.L10N.register(
     "The conversation is now open to everyone" : "La conversacion es ara dubèrta a tot lo monde",
     "{actor} opened the conversation to everyone" : "{actor} a dubèrta la conversacion a tot lo monde",
     "You opened the conversation to everyone" : "Avètz dobèrta la conversacion a tot lo monde",
+    "You allowed guests" : "Avètz autorizat los convidats",
+    "You disallowed guests" : "Avètz interdich los convidats",
+    "An administrator disallowed guests" : "Un administrator desactivèt los convidats",
     "{actor} set a password" : "{actor} a definit un senhal",
     "You set a password" : "Avètz definit un senhal",
     "An administrator set a password" : "Un administrator a definit un senhal",
@@ -76,16 +82,29 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
     "Talk to %s" : "Parlar a %s",
+    "No account available to delete." : "Cap de compte pas disponible per la supression.",
     "Talk mentions" : "Mencions Talk",
     "Write to conversation" : "Escriure dins la conversacion",
+    "%s invited you to a conversation." : "%s vos a convidat a una conversacion.",
+    "You were invited to a conversation." : "Òm vos a convidat a una conversacion.",
+    "Conversation invitation" : "Convit de conversacion",
     "Meeting ID" : "Identificant reünion",
     "Your PIN" : "Vòstre còdi",
+    "Password request: %s" : "Senhal requerit : %s",
     "Private conversation" : "Conversacion privada",
+    "Deleted user (%s)" : "Utilizaire suprimit (%s)",
+    "{user} in {call}" : "{user} dins {call}",
+    "Deleted user in {call}" : "Utilizaire suprimit dins {call}",
+    "Answer call" : "Respondre a l’apèl",
     "{user} would like to talk with you" : "{user} volriá vos parlar",
+    "Call back" : "Tornar",
+    "You missed a call from {user}" : "Avètz mancat una sonada de {user}",
     "Open settings" : "Dobrir los paramètres",
     "Conversations" : "Discussions",
     "Messages" : "Messatges",
     "{user}" : "{user}",
+    "Messages in {conversation}" : "Messatges dins {conversation}",
+    "{user} in {conversation}" : "{user} dins {conversation}",
     "The URL is invalid." : "L’URL es invalida",
     "An HTTPS URL is required." : "Una URL HTTPS es requerida.",
     "The email address is invalid." : "L’adreça email es invalida.",
@@ -344,6 +363,7 @@ OC.L10N.register(
     "General settings" : "Paramètres generals",
     "All messages" : "Totes los messatges",
     "Off" : "Atudat",
+    "URL of this Nextcloud instance" : "URL d’aquesta instància Nextcloud",
     "Language" : "Lenga",
     "Country" : "País",
     "Status" : "Estatut",
@@ -360,12 +380,20 @@ OC.L10N.register(
     "Install Talk Matterbridge" : "Installar Talk Matterbridge",
     "Installed version: {version}" : "Version installada : {version}",
     "An error occurred while installing the Talk Matterbridge. Please install it manually." : "Una error s’es producha pendent l’installacion de Talk Matterbridge. Volgatz l’installar manualament.",
+    "SIP configuration" : "Configuracion SIP",
+    "Shared secret" : "Secret partejat",
+    "Validate SSL certificate" : "Validar lo certificat SSL",
     "Delete this server" : "Suprimir aqueste servidor",
+    "Status: Checking connection" : "Estat : verificacion de la connexion",
+    "OK: Running version: {version}" : "OK : execucion de la version : {version}",
+    "Error: Can not connect to server" : "Error : connexion impossibla al servidor",
     "Saved" : "Enregistrat",
     "Add a new server" : "Apondre un servidor novèl",
     "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Es forçadament recomandat de configurar a cache distribuit pendent l’utilizacion de Nextcloud Talk amb un back-end de fòrt rendiment.",
     "STUN server URL" : "URL servidor STUN",
     "STUN servers" : "Servidors STUN",
+    "{option1} and {option2}" : "{option1} e {option2}",
+    "{option} only" : "{option} sonque",
     "TURN server URL" : "URL servidor TURN",
     "TURN server secret" : "Secrèt servidor TURN",
     "TURN server protocols" : "Protocòls servidor TURN",
@@ -376,6 +404,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "Partejatz aqueste ligam per convidar mai de monde !",
     "Conversation link copied to clipboard." : "Ligam de conversacion copiat al quichapapièrs.",
     "Stop screensharing" : "Arrestar partiment d’ecran",
+    "More actions" : "Mai d’accions",
     "Settings" : "Paramètres",
     "Dismiss" : "Regetar",
     "No audio" : "Cap d’àudio",
@@ -395,10 +424,30 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
     "An error occurred while starting screensharing." : "S’es producha una error en aviant lo partiment d’ecran.",
     "Back" : "Retorn",
+    "Show screen" : "Far veire l’ecran",
     "Mute" : "Mut",
+    "Stop following" : "Quitar de seguir",
+    "Post message" : "Publicar messatge",
+    "This conversation is read-only" : "Aquesta conversacion es en lectura sola",
+    "Call in progress" : "Sonada en cors",
     "Favorite" : "Favorit",
-    "Password protection" : "Password protection",
+    "Conversation settings" : "Paramètres de conversacion",
+    "Chat notifications" : "Notificacions de chat",
+    "Guests access" : "Accès convidat",
+    "Meeting settings" : "Paramètres de reünion",
+    "Leave conversation" : "Quitar la conversacion",
+    "Delete conversation" : "Suprimir la conversacion",
+    "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
+    "Allow guests" : "Autorizar los convidats",
+    "Password protection" : "Protegir via senhal",
     "Enter a password" : "Picatz un senhal",
+    "Save password" : "Enregistrar lo senhal",
+    "Copy conversation link" : "Copiar lo ligam de conversacion",
+    "Resend invitations" : "Tornar enviar las invitacions",
+    "Invitations sent" : "Invitacions enviadas",
+    "Enable lobby" : "Activar la sala d’espèra",
+    "After the time limit the lobby will be automatically disabled." : "Aprèp la limita de temps la sala d’espèra serà automaticament desactivada.",
+    "Lock conversation" : "Verrolhar la conversacion",
     "Save" : "Salvar",
     "Edit" : "Modificar",
     "More information" : "Mai d’informacions",
@@ -407,6 +456,8 @@ OC.L10N.register(
     "Nextcloud user" : "Utilizaire Nextcloud",
     "User password" : "Senhal utilizaire",
     "Talk conversation" : "Conversacion Talk",
+    "Matrix server URL" : "URL servidor Matrix",
+    "Matrix channel" : "Cadena Matrix",
     "Team name" : "Nom de la còla",
     "Channel name" : "Nom de la cadena",
     "Password" : "Senhal",
@@ -414,24 +465,48 @@ OC.L10N.register(
     "Channel" : "Cadena",
     "Login" : "Login",
     "Nickname" : "Escais",
+    "Connection password" : "Senhal de connexion",
+    "IRC channel" : "Cadena IRC",
+    "Channel password" : "Senhal de cadena",
+    "NickServ nickname" : "Nom d’utilizaire NickServ",
+    "NickServ password" : "Senhal NickServ",
     "Use TLS" : "Utilizar TLS",
     "Use SASL" : "Utilizar SASL",
     "Skip TLS verification" : "Passar la verificacion TLS",
+    "Tenant ID" : "ID Tenant",
     "Client ID" : "ID client",
+    "Team ID" : "ID Team",
+    "Jabber ID" : "ID Jabber",
+    "unknown state" : "estat desconegut",
     "running" : "en cors d'execucion",
-    "Delete conversation" : "Suprimir la conversacion",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
+    "You: {lastMessage}" : "Vos : {lastMessage}",
+    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "No matches" : "Cap de resultat correspond pas",
     "Conversation list" : "Lista de conversacion",
+    "Open conversations" : "Dobrir las conversacions",
     "Loading" : "Loading",
     "No search results" : "pas cap de resultats de recèrca",
     "Groups" : "Gropes",
     "Circles" : "Cercles",
     "Talk settings" : "Paramètres Talk",
     "Users and groups" : "Utilizaires e grops",
+    "Creating your conversation" : "Creacion de vòstra conversacion",
+    "Create a new group conversation" : "Crear una conversacion de grop novèla",
     "Password protect" : "Protegir per un senhal",
+    "Add participants" : "Apondre participants",
+    "Create conversation" : "Crear conversacion",
     "Close" : "Tampar",
+    "Choose a password" : "Causir un senhal",
+    "Search participants" : "Cercar participants",
+    "Conversation name" : "Nom de conversacion",
+    "Allow guests to join via link" : "Permetre als convidats de rejónher via ligam",
+    "You are currently waiting in the lobby" : "Sètz a esperar dins la sala d’espèra",
+    "Access to microphone is only possible with HTTPS" : "L’accès al microfòn es sonque possibla amb HTTPS",
+    "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
+    "Error while accessing microphone" : "Error pendent l’accès al microfòn",
+    "Access to camera is only possible with HTTPS" : "L’accès a la camèra es sonque possibla amb HTTPS",
     "Microphone" : "Microfòn",
     "Camera" : "Camèra",
     "No microphone available" : "Cap de microfòn pas disponible",
@@ -441,22 +516,40 @@ OC.L10N.register(
     "Reply" : "Respondre",
     "Sending message" : "Mandadís del messatge",
     "Message sent" : "Messatge mandat",
+    "Deleting message" : "Supression del messatge",
     "Remove" : "Suprimir",
     "Today" : "Uèi",
     "Yesterday" : "Ièr",
+    "Upload new files" : "Enviar fichièrs novèls",
     "Add emoji" : "Apondre emoji",
     "Send message" : "Enviar un messatge",
     "File to share" : "Fichièr de partejar",
     "This conversation has been locked" : "Aquesta conversacion foguèt clavada",
     "Write message, @ to mention someone …" : "Escriure un messatge, @ per mencionar qualqu’un…",
     "Description" : "Descripcion",
+    "Disable lobby" : "Desactivar la sala d’espèra",
+    "moderator" : "moderator",
     "guest" : "convidat",
+    "Add participant \"{user}\"" : "Apondre participant « {user} »",
+    "Participant \"{user}\"" : "Participant « {user} »",
+    "Joined with audio" : "Rejonhèt amb l’àudio",
+    "Joined with video" : "Rejonhèt amb vidèo",
+    "Joined via phone" : "Rejonhèt via telefòn",
+    "Raised their hand" : "Levèt la man",
+    "Add users" : "Apondre utilizaires",
+    "Add groups" : "Apondre grops",
+    "Add emails" : "Apondre emails",
     "Searching …" : "Recèrca…",
     "No results" : "Pas cap de resultat",
     "Add users or groups" : "Add users or groups",
     "Participants" : "Participants",
+    "Search or add participants" : "Cercar o apondre participants",
+    "Add a description for this conversation" : "Apondre una descripcion per aquesta conversacion",
     "Chat" : "Messatjariá",
+    "Details" : "Detalhs",
     "Display name: " : "Nom d’afichatge :",
+    "Choose devices" : "Causir periferics",
+    "Privacy" : "Confidencialitat",
     "Keyboard shortcuts" : "Acorchis de clavièr",
     "Speed up your Talk experience with these quick shortcuts." : "Acceleratz vòstra experiéncia Talk amb aqueles acorchis.",
     "Search" : "Search",
@@ -471,16 +564,29 @@ OC.L10N.register(
     "Fullscreen (f)" : "Ecran complèt (f)",
     "Grid view" : "Vista en grasilha",
     "Send" : "Mandar",
+    "Start a conversation" : "Començar una conversacion",
+    "You were mentioned" : "Qualqu’un vos a mencionat",
+    "Message without mention" : "Messatge sens mencion",
+    "No conversations found" : "Cap de conversacion pas trobada",
+    "Select conversation" : "Seleccionar una conversacion",
+    "Link to a conversation" : "Ligam cap a la conversacion",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Avètz rejonch la conversacion dins una autra fenèstra o periferic. Aquò es actualament pas pres en cargar per Nextcloud Talk doncas aquesta session es estada tampada.",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
+    "Do not disturb" : "Me desrengar pas",
     "Away" : "Absent",
+    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
+    "Error while sharing file" : "Error pendent lo partiment del fichièr",
     "Leave this page" : "Quitar aquesta pagina",
     "Default" : "Defaut",
     "Microphone {number}" : "Microfòn {number}",
     "Camera {number}" : "Camèra {number}",
     "Speaker {number}" : "Naut-parlaire {number}",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Sembla que parlatz mentre que lo son es copat, mercés de vos restablir lo son per que vos entendan los autres",
+    "Access to microphone & camera is only possible with HTTPS" : "L’accès al microfòn e a la camèra es sonque possibla amb HTTPS",
+    "Please move your setup to HTTPS" : "Mercés de passar vòstra configuracion al HTTPS",
+    "Access to microphone & camera was denied" : "L’accès al microfòn e a la camèra es estat refusat",
+    "WebRTC is not supported in your browser" : "Vòstre navegador pren pas en carga lo WebRTC",
     "This conversation is password-protected" : "Aquesta conversacion es protegida per senhal",
     "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
     "TURN server" : "Servidor TURN",
@@ -496,11 +602,16 @@ OC.L10N.register(
     "UDP only" : "Sonque UDP",
     "TCP only" : "Sonque TCP",
     "Conversation, " : "Conversacion, ",
+    "Allow guests to join via link " : "Permetre als convidats de rejónher via ligam",
+    "Add participants to the conversation" : "Apondre participants a la conversacion",
     "Projects" : "Projèctes",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada",
     "Share link" : "Partejar lo ligam",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
     "New in Talk 10" : "Nòu dins Talk 10",
-    "Enabled" : "Activada"
+    "Enabled" : "Activada",
+    "turn: and turns:" : "turn: e turns:",
+    "turn: only" : "turn: sonque",
+    "turns: only" : "turns: sonque"
 },
 "nplurals=2; plural=(n > 1);");
