@@ -256,17 +256,23 @@ OC.L10N.register(
     "Blocked" : "Blocat",
     "Saved" : "Salvat",
     "Copy link" : "Copiză link",
+    "Settings" : "Setări",
     "Dismiss" : "Elimină",
     "Back" : "Înapoi",
     "Favorite" : "Favorite",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
+    "Save" : "Salvează",
+    "Edit" : "Editează",
+    "Password" : "Parolă",
+    "Login" : "Autentificare",
+    "Nickname" : "Pseudonim",
+    "Client ID" : "ID client",
     "Remove from favorites" : "Șterge din favorite",
     "Add to favorites" : "Adăugați la favorite",
     "Loading" : "Loading",
     "Groups" : "Grupuri",
     "Circles" : "Cercuri",
-    "Settings" : "Setări",
     "Password protect" : "Protejare cu parolă",
     "Close" : "Închide",
     "Camera" : "Cameră",
@@ -274,16 +280,9 @@ OC.L10N.register(
     "Remove" : "Șterge",
     "Today" : "Azi",
     "Yesterday" : "Ieri",
-    "Enabled" : "Activat",
-    "Save" : "Salvează",
-    "Password" : "Parolă",
-    "Login" : "Autentificare",
-    "Nickname" : "Pseudonim",
-    "Client ID" : "ID client",
     "guest" : "invitat",
     "No results" : "Niciun rezultat",
     "Add users or groups" : "Add users or groups",
-    "Edit" : "Editează",
     "Keyboard shortcuts" : "Scurtături din tastatură",
     "Search" : "Caută",
     "Grid view" : "Afișare în grilă",
@@ -293,11 +292,7 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
     "Android app" : "Aplicație Android",
     "iOS app" : "Aplicație iOS",
-    "Contacts" : "Contacte",
     "Share link" : "Partajează link-ul",
-    "Limit app usage to groups." : "Limitare utilizare aplicație la grupuri",
-    "Password required" : "Parola este necesară",
-    "Cancel" : "Anulează",
-    "Submit" : "Trimite"
+    "Enabled" : "Activat"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
