@@ -279,17 +279,18 @@ OC.L10N.register(
     "Back" : "返回",
     "You" : "您",
     "Favorite" : "我的最愛",
+    "Leave conversation" : "離開對話",
+    "Delete conversation" : "刪除對話",
     "Password protection" : "密碼保護",
     "Enter a password" : "輸入密碼",
     "Save" : "儲存",
     "Edit" : "編輯",
+    "Delete" : "刪除",
     "Password" : "密碼",
     "API token" : "API token",
     "Login" : "帳號",
     "Nickname" : "暱稱",
     "Client ID" : "客戶端ID",
-    "Leave conversation" : "離開對話",
-    "Delete conversation" : "刪除對話",
     "Remove from favorites" : "取消我的最愛",
     "Add to favorites" : "加到我的最愛",
     "Loading" : "載入中",
@@ -298,7 +299,6 @@ OC.L10N.register(
     "Password protect" : "密碼防護",
     "Close" : "關閉",
     "Conversation name" : "對話名稱",
-    "Allow guests to join via link " : "允許訪客透過連結加入",
     "Camera" : "相機",
     "Reply" : "回覆",
     "Remove" : "移除",
@@ -309,6 +309,7 @@ OC.L10N.register(
     "Invalid path selected" : "所選的路徑無效",
     "moderator" : "主持人",
     "guest" : "訪客",
+    "Searching …" : "正在搜尋……",
     "No results" : "沒有符合搜尋的項目",
     "Add users or groups" : "增加使用者或者群組",
     "Participants" : "參與者",
@@ -331,6 +332,7 @@ OC.L10N.register(
     "UDP and TCP" : "UDP 和 TCP",
     "UDP only" : "僅UDP",
     "TCP only" : "僅TCP",
+    "Allow guests to join via link " : "允許訪客透過連結加入",
     "Projects" : "專案項目",
     "Share link" : "分享連結",
     "Enabled" : "已啟用"
