@@ -23,7 +23,8 @@ declare(strict_types=1);
 
 namespace OCA\Talk\BackgroundJob;
 
-use OC\BackgroundJob\TimedJob;
+use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\BackgroundJob\TimedJob;
 use OCA\Talk\Manager;
 use OCP\ICache;
 use OCP\ICacheFactory;
@@ -35,8 +36,11 @@ class ResetAssignedSignalingServer extends TimedJob {
 	/** @var ICache */
 	protected $cache;
 
-	public function __construct(Manager $manager,
+	public function __construct(ITimeFactory $time,
+								Manager $manager,
 								ICacheFactory $cacheFactory) {
+		parent::__construct($time);
+
 		// Every 5 minutes
 		$this->setInterval(60 * 5);
 
