@@ -61,7 +61,7 @@ class ChatManager {
 
 	public const MAX_CHAT_LENGTH = 32000;
 
-	/** @var CommentsManager|ICommentsManager */
+	/** @var ICommentsManager */
 	private $commentsManager;
 	/** @var IEventDispatcher */
 	private $dispatcher;
@@ -106,14 +106,30 @@ class ChatManager {
 	 * @param \DateTime $creationDateTime
 	 * @param bool $sendNotifications
 	 * @param string|null $referenceId
+	 * @param int|null $parentId
 	 * @return IComment
 	 */
-	public function addSystemMessage(Room $chat, string $actorType, string $actorId, string $message, \DateTime $creationDateTime, bool $sendNotifications, ?string $referenceId = null): IComment {
+	public function addSystemMessage(
+		Room $chat,
+		string $actorType,
+		string $actorId,
+		string $message,
+		\DateTime $creationDateTime,
+		bool $sendNotifications,
+		?string $referenceId = null,
+		?int $parentId = null
+	): IComment {
 		$comment = $this->commentsManager->create($actorType, $actorId, 'chat', (string) $chat->getId());
 		$comment->setMessage($message, self::MAX_CHAT_LENGTH);
 		$comment->setCreationDateTime($creationDateTime);
 		if ($referenceId !== null) {
-			$comment->setReferenceId($referenceId);
+			$referenceId = trim(substr($referenceId, 0, 40));
+			if ($referenceId !== '') {
+				$comment->setReferenceId($referenceId);
+			}
+		}
+		if ($parentId !== null) {
+			$comment->setParentId((string) $parentId);
 		}
 		$comment->setVerb('system');
 
@@ -231,6 +247,30 @@ class ChatManager {
 		return $comment;
 	}
 
+	public function deleteMessage(Room $chat, int $messageId, string $actorType, string $actorId, \DateTime $deletionTime): IComment {
+		$comment = $this->getComment($chat, (string) $messageId);
+		$comment->setMessage(
+			json_encode([
+				'deleted_by_type' => $actorType,
+				'deleted_by_id' => $actorId,
+				'deleted_on' => $deletionTime->getTimestamp(),
+			])
+		);
+		$comment->setVerb('comment_deleted');
+		$this->commentsManager->save($comment);
+
+		return $this->addSystemMessage(
+			$chat,
+			$actorType,
+			$actorId,
+			json_encode(['message' => 'message_deleted', 'parameters' => ['message' => $messageId]]),
+			$this->timeFactory->getDateTime(),
+			false,
+			null,
+			$messageId
+		);
+	}
+
 	/**
 	 * @param Room $chat
 	 * @param string $parentId
@@ -247,6 +287,22 @@ class ChatManager {
 		return $comment;
 	}
 
+	/**
+	 * @param Room $chat
+	 * @param string $messageId
+	 * @return IComment
+	 * @throws NotFoundException
+	 */
+	public function getComment(Room $chat, string $messageId): IComment {
+		$comment = $this->commentsManager->get($messageId);
+
+		if ($comment->getObjectType() !== 'chat' || $comment->getObjectId() !== (string) $chat->getId()) {
+			throw new NotFoundException('Message not found in the right context');
+		}
+
+		return $comment;
+	}
+
 	public function getLastReadMessageFromLegacy(Room $chat, IUser $user): int {
 		$marker = $this->commentsManager->getReadMark('chat', $chat->getId(), $user);
 		if ($marker === null) {
@@ -260,6 +316,17 @@ class ChatManager {
 		return $this->commentsManager->getNumberOfCommentsForObjectSinceComment('chat', (string) $chat->getId(), $lastReadMessage, 'comment');
 	}
 
+	/**
+	 * Returns the ID of the last chat message, that was read by everyone
+	 * sharing their read status.
+	 *
+	 * @param Room $chat
+	 * @return int
+	 */
+	public function getLastCommonReadMessage(Room $chat): int {
+		return $this->participantService->getLastCommonReadChatMessage($chat);
+	}
+
 	/**
 	 * Receive the history of a chat
 	 *
