@@ -27,6 +27,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Controller;
 
+use OCA\Talk\GuestManager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
@@ -35,20 +36,30 @@ use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\IRequest;
+use OCP\IUser;
+use OCP\IUserManager;
 
 class CallController extends AEnvironmentAwareController {
 
 	/** @var ParticipantService */
 	private $participantService;
+	/** @var IUserManager */
+	private $userManager;
+	/** @var GuestManager */
+	private $guestManager;
 	/** @var ITimeFactory */
 	private $timeFactory;
 
 	public function __construct(string $appName,
 								IRequest $request,
 								ParticipantService $participantService,
+								IUserManager $userManager,
+								GuestManager $guestManager,
 								ITimeFactory $timeFactory) {
 		parent::__construct($appName, $request);
 		$this->participantService = $participantService;
+		$this->userManager = $userManager;
+		$this->guestManager = $guestManager;
 		$this->timeFactory = $timeFactory;
 	}
 
@@ -64,6 +75,24 @@ class CallController extends AEnvironmentAwareController {
 		$timeout = $this->timeFactory->getTime() - 30;
 		$result = [];
 		$participants = $this->participantService->getParticipantsInCall($this->room);
+
+
+		$guestSessions = array_filter(array_map(static function (Participant $participant) use ($timeout) {
+			$session = $participant->getSession();
+			if (!$session || $participant->getAttendee()->getActorType() !== Attendee::ACTOR_GUESTS) {
+				return null;
+			}
+
+			if ($session->getLastPing() < $timeout) {
+				// User is not active in call
+				return null;
+			}
+
+			return sha1($session->getSessionId());
+		}, $participants));
+
+		$guestNames = $this->guestManager->getNamesBySessionHashes($guestSessions);
+
 		foreach ($participants as $participant) {
 			/** @var Session $session */
 			$session = $participant->getSession();
@@ -73,11 +102,20 @@ class CallController extends AEnvironmentAwareController {
 			}
 
 			if ($this->getAPIVersion() >= 3) {
+				$displayName = $participant->getAttendee()->getActorId();
+				if ($participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS) {
+					$user = $this->userManager->get($participant->getAttendee()->getActorId());
+					if ($user instanceof IUser) {
+						$displayName = $user->getDisplayName();
+					}
+				} else {
+					$displayName = $guestNames[$participant->getAttendee()->getActorId()] ?? '';
+				}
+
 				$result[] = [
 					'actorType' => $participant->getAttendee()->getActorType(),
 					'actorId' => $participant->getAttendee()->getActorId(),
-					// FIXME 'displayName' => $participant->getAttendee()->getDisplayName(),
-					'displayName' => $participant->getAttendee()->getActorId(),
+					'displayName' => $displayName,
 					'token' => $this->room->getToken(),
 					'lastPing' => $session->getLastPing(),
 					'sessionId' => $session->getSessionId(),
