@@ -106,6 +106,9 @@ class RoomController extends AEnvironmentAwareController {
 	/** @var Config */
 	protected $talkConfig;
 
+	/** @var array */
+	protected $commonReadMessages = [];
+
 	public function __construct(string $appName,
 								?string $UserId,
 								IRequest $request,
@@ -195,8 +198,14 @@ class RoomController extends AEnvironmentAwareController {
 			}
 		}
 
-
 		$rooms = $this->manager->getRoomsForUser($this->userId, true);
+		$readPrivacy = $this->talkConfig->getUserReadPrivacy($this->userId);
+		if ($readPrivacy === Participant::PRIVACY_PUBLIC) {
+			$roomIds = array_map(static function (Room $room) {
+				return $room->getId();
+			}, $rooms);
+			$this->commonReadMessages = $this->participantService->getLastCommonReadChatMessageForMultipleRooms($roomIds);
+		}
 
 		$return = [];
 		foreach ($rooms as $room) {
@@ -210,6 +219,32 @@ class RoomController extends AEnvironmentAwareController {
 		return new DataResponse($return, Http::STATUS_OK, $this->getTalkHashHeader());
 	}
 
+	/**
+	 * Get listed rooms with optional search term
+	 *
+	 * @NoAdminRequired
+	 *
+	 * @param string $searchTerm search term
+	 * @return DataResponse
+	 */
+	public function getListedRooms(string $searchTerm = ''): DataResponse {
+		$event = new UserEvent($this->userId);
+
+		$rooms = $this->manager->getListedRoomsForUser($this->userId, $searchTerm);
+
+		$return = [];
+		foreach ($rooms as $room) {
+			try {
+				$return[] = $this->formatRoomV2andV3($room, null);
+			} catch (RoomNotFoundException $e) {
+			} catch (\RuntimeException $e) {
+			}
+		}
+
+		return new DataResponse($return, Http::STATUS_OK);
+	}
+
+
 	/**
 	 * @PublicPage
 	 *
@@ -231,7 +266,7 @@ class RoomController extends AEnvironmentAwareController {
 		$includeLastMessage = !$isSIPBridgeRequest;
 
 		try {
-			$room = $this->manager->getRoomForUserByToken($token, $this->userId, $includeLastMessage);
+			$room = $this->manager->getRoomForUserByToken($token, $this->userId, $includeLastMessage, $isSIPBridgeRequest);
 
 			$participant = null;
 			try {
@@ -548,6 +583,10 @@ class RoomController extends AEnvironmentAwareController {
 				'attendeeId' => 0,
 				'canEnableSIP' => false,
 				'attendeePin' => '',
+				'description' => '',
+				'lastCommonReadMessage' => 0,
+				'listable' => Room::LISTABLE_NONE,
+				'callFlag' => Participant::FLAG_DISCONNECTED,
 			]);
 		}
 
@@ -565,18 +604,22 @@ class RoomController extends AEnvironmentAwareController {
 			$lobbyTimer = 0;
 		}
 
-		if ($isSIPBridgeRequest) {
+		if ($isSIPBridgeRequest
+			|| ($room->getListable() !== Room::LISTABLE_NONE && !$currentParticipant instanceof Participant)
+		) {
 			return array_merge($roomData, [
 				'name' => $room->getName(),
-				'displayName' => $room->getDisplayName(''),
+				'displayName' => $room->getDisplayName($isSIPBridgeRequest || $this->userId === null ? '' : $this->userId),
 				'objectType' => $room->getObjectType(),
 				'objectId' => $room->getObjectId(),
 				'readOnly' => $room->getReadOnly(),
 				'hasCall' => $room->getActiveSince() instanceof \DateTimeInterface,
 				'lastActivity' => $lastActivity,
+				'callFlag' => $room->getCallFlag(),
 				'lobbyState' => $room->getLobbyState(),
 				'lobbyTimer' => $lobbyTimer,
 				'sipEnabled' => $room->getSIPEnabled(),
+				'listable' => $room->getListable(),
 			]);
 		}
 
@@ -596,6 +639,7 @@ class RoomController extends AEnvironmentAwareController {
 			'readOnly' => $room->getReadOnly(),
 			'hasCall' => $room->getActiveSince() instanceof \DateTimeInterface,
 			'lastActivity' => $lastActivity,
+			'callFlag' => $room->getCallFlag(),
 			'isFavorite' => $attendee->isFavorite(),
 			'notificationLevel' => $attendee->getNotificationLevel(),
 			'lobbyState' => $room->getLobbyState(),
@@ -616,7 +660,17 @@ class RoomController extends AEnvironmentAwareController {
 				'actorType' => $attendee->getActorType(),
 				'actorId' => $attendee->getActorId(),
 				'attendeeId' => $attendee->getId(),
+				'description' => $room->getDescription(),
+				'listable' => $room->getListable(),
 			]);
+
+			if ($currentParticipant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
+				if (isset($this->commonReadMessages[$room->getId()])) {
+					$roomData['lastCommonReadMessage'] = $this->commonReadMessages[$room->getId()];
+				} else {
+					$roomData['lastCommonReadMessage'] = $this->chatManager->getLastCommonReadMessage($room);
+				}
+			}
 		}
 
 		$session = $currentParticipant->getSession();
@@ -997,6 +1051,27 @@ class RoomController extends AEnvironmentAwareController {
 		return new DataResponse();
 	}
 
+	/**
+	 * @PublicPage
+	 * @RequireModeratorParticipant
+	 *
+	 * @param string $description
+	 * @return DataResponse
+	 */
+	public function setDescription(string $description): DataResponse {
+		if ($this->room->getType() === Room::ONE_TO_ONE_CALL) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
+		try {
+			$this->room->setDescription($description);
+		} catch (\LengthException $exception) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
+		return new DataResponse();
+	}
+
 	/**
 	 * @PublicPage
 	 * @RequireModeratorParticipant
@@ -1433,6 +1508,21 @@ class RoomController extends AEnvironmentAwareController {
 		return new DataResponse();
 	}
 
+	/**
+	 * @NoAdminRequired
+	 * @RequireModeratorParticipant
+	 *
+	 * @param int $state
+	 * @return DataResponse
+	 */
+	public function setListable(int $scope): DataResponse {
+		if (!$this->room->setListable($scope)) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
+		return new DataResponse();
+	}
+
 	/**
 	 * @PublicPage
 	 * @RequireModeratorParticipant
@@ -1616,7 +1706,7 @@ class RoomController extends AEnvironmentAwareController {
 			} elseif ($userId !== null) {
 				$targetParticipant = $this->room->getParticipant($userId);
 			} else {
-				$targetParticipant =  $this->room->getParticipantBySession($sessionId);
+				$targetParticipant = $this->room->getParticipantBySession($sessionId);
 			}
 		} catch (ParticipantNotFoundException $e) {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
@@ -1724,4 +1814,35 @@ class RoomController extends AEnvironmentAwareController {
 
 		return new DataResponse($this->formatRoomV2andV3($this->room, $this->participant));
 	}
+
+	/**
+	 * @NoAdminRequired
+	 * @RequireModeratorParticipant
+	 *
+	 * @param int|null $attendeeId attendee id
+	 * @return DataResponse
+	 */
+	public function resendInvitations(?int $attendeeId): DataResponse {
+		$participants = [];
+
+		// targetting specific participant
+		if ($attendeeId !== null) {
+			try {
+				$participants[] = $this->room->getParticipantByAttendeeId($attendeeId);
+			} catch (ParticipantNotFoundException $e) {
+				return new DataResponse([], Http::STATUS_NOT_FOUND);
+			}
+		} else {
+			$participants = $this->participantService->getParticipantsForRoom($this->room);
+		}
+
+		foreach ($participants as $participant) {
+			if ($participant->getAttendee()->getActorType() === Attendee::ACTOR_EMAILS) {
+				// generate PIN if applicable
+				$this->participantService->generatePinForParticipant($this->room, $participant);
+				$this->guestManager->sendEmailInvitation($this->room, $participant);
+			}
+		}
+		return new DataResponse();
+	}
 }
