@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 /**
  * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
@@ -22,10 +23,10 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Listener;
 
-
 use OCA\Talk\Events\ModifyParticipantEvent;
 use OCA\Talk\Exceptions\ForbiddenException;
 use OCA\Talk\Room;
+use OCA\Talk\Service\ParticipantService;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
 
@@ -34,12 +35,17 @@ class RestrictStartingCalls {
 	/** @var IConfig */
 	protected $config;
 
-	public function __construct(IConfig $config) {
+	/** @var ParticipantService */
+	protected $participantService;
+
+	public function __construct(IConfig $config,
+								ParticipantService $participantService) {
 		$this->config = $config;
+		$this->participantService = $participantService;
 	}
 
 	public static function register(IEventDispatcher $dispatcher): void {
-		$dispatcher->addListener(Room::EVENT_BEFORE_SESSION_JOIN_CALL, static function(ModifyParticipantEvent $event) {
+		$dispatcher->addListener(Room::EVENT_BEFORE_SESSION_JOIN_CALL, static function (ModifyParticipantEvent $event) {
 			/** @var self $listener */
 			$listener = \OC::$server->query(self::class);
 			$listener->checkStartCallPermissions($event);
@@ -54,7 +60,7 @@ class RestrictStartingCalls {
 		$room = $event->getRoom();
 		$participant = $event->getParticipant();
 
-		if (!$participant->canStartCall() && !$room->hasSessionsInCall()) {
+		if (!$participant->canStartCall($this->config) && !$this->participantService->hasActiveSessionsInCall($room)) {
 			throw new ForbiddenException('Can not start a call');
 		}
 	}
