@@ -23,17 +23,19 @@ declare(strict_types=1);
 
 namespace OCA\Talk;
 
-use OCA\Talk\Chat\Changelog;
 use OCA\Talk\Chat\CommentsManager;
 use OCA\Talk\Events\RoomEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\AttendeeMapper;
+use OCA\Talk\Model\SelectHelper;
 use OCA\Talk\Model\SessionMapper;
 use OCA\Talk\Service\ParticipantService;
+use OCP\App\IAppManager;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
+use OCP\Comments\ICommentsManager;
 use OCP\Comments\NotFoundException;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
@@ -43,6 +45,7 @@ use OCP\IDBConnection;
 use OCP\IL10N;
 use OCP\IUser;
 use OCP\IUserManager;
+use OCP\IGroupManager;
 use OCP\Security\IHasher;
 use OCP\Security\ISecureRandom;
 
@@ -55,6 +58,8 @@ class Manager {
 	private $config;
 	/** @var Config */
 	private $talkConfig;
+	/** @var IAppManager */
+	private $appManager;
 	/** @var AttendeeMapper */
 	private $attendeeMapper;
 	/** @var SessionMapper */
@@ -65,7 +70,9 @@ class Manager {
 	private $secureRandom;
 	/** @var IUserManager */
 	private $userManager;
-	/** @var CommentsManager */
+	/** @var IGroupManager */
+	private $groupManager;
+	/** @var ICommentsManager */
 	private $commentsManager;
 	/** @var TalkSession */
 	private $talkSession;
@@ -81,11 +88,13 @@ class Manager {
 	public function __construct(IDBConnection $db,
 								IConfig $config,
 								Config $talkConfig,
+								IAppManager $appManager,
 								AttendeeMapper $attendeeMapper,
 								SessionMapper $sessionMapper,
 								ParticipantService $participantService,
 								ISecureRandom $secureRandom,
 								IUserManager $userManager,
+								IGroupManager $groupManager,
 								CommentsManager $commentsManager,
 								TalkSession $talkSession,
 								IEventDispatcher $dispatcher,
@@ -95,11 +104,13 @@ class Manager {
 		$this->db = $db;
 		$this->config = $config;
 		$this->talkConfig = $talkConfig;
+		$this->appManager = $appManager;
 		$this->attendeeMapper = $attendeeMapper;
 		$this->sessionMapper = $sessionMapper;
 		$this->participantService = $participantService;
 		$this->secureRandom = $secureRandom;
 		$this->userManager = $userManager;
+		$this->groupManager = $groupManager;
 		$this->commentsManager = $commentsManager;
 		$this->talkSession = $talkSession;
 		$this->dispatcher = $dispatcher;
@@ -110,9 +121,9 @@ class Manager {
 
 	public function forAllRooms(callable $callback): void {
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('id', 'r_id')
-			->from('talk_rooms');
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r');
 
 		$result = $query->execute();
 		while ($row = $result->fetch()) {
@@ -167,13 +178,16 @@ class Manager {
 			(int) $row['r_id'],
 			(int) $row['type'],
 			(int) $row['read_only'],
+			(int) $row['listable'],
 			(int) $row['lobby_state'],
 			(int) $row['sip_enabled'],
 			$assignedSignalingServer,
 			(string) $row['token'],
 			(string) $row['name'],
+			(string) $row['description'],
 			(string) $row['password'],
 			(int) $row['active_guests'],
+			(int) $row['call_flag'],
 			$activeSince,
 			$lastActivity,
 			(int) $row['last_message'],
@@ -200,21 +214,22 @@ class Manager {
 	}
 
 	public function createCommentObject(array $row): ?IComment {
+		/** @psalm-suppress UndefinedInterfaceMethod */
 		return $this->commentsManager->getCommentFromData([
-			'id'				=> $row['comment_id'],
-			'parent_id'			=> $row['comment_parent_id'],
-			'topmost_parent_id'	=> $row['comment_topmost_parent_id'],
-			'children_count'	=> $row['comment_children_count'],
-			'message'			=> $row['comment_message'],
-			'verb'				=> $row['comment_verb'],
-			'actor_type'		=> $row['comment_actor_type'],
-			'actor_id'			=> $row['comment_actor_id'],
-			'object_type'		=> $row['comment_object_type'],
-			'object_id'			=> $row['comment_object_id'],
+			'id' => $row['comment_id'],
+			'parent_id' => $row['comment_parent_id'],
+			'topmost_parent_id' => $row['comment_topmost_parent_id'],
+			'children_count' => $row['comment_children_count'],
+			'message' => $row['comment_message'],
+			'verb' => $row['comment_verb'],
+			'actor_type' => $row['comment_actor_type'],
+			'actor_id' => $row['comment_actor_id'],
+			'object_type' => $row['comment_object_type'],
+			'object_id' => $row['comment_object_id'],
 			// Reference id column might not be there, so we need to fallback to null
-			'reference_id'		=> $row['comment_reference_id'] ?? null,
-			'creation_timestamp'		=> $row['comment_creation_timestamp'],
-			'latest_child_timestamp'	=> $row['comment_latest_child_timestamp'],
+			'reference_id' => $row['comment_reference_id'] ?? null,
+			'creation_timestamp' => $row['comment_creation_timestamp'],
+			'latest_child_timestamp' => $row['comment_latest_child_timestamp'],
 		]);
 	}
 
@@ -228,9 +243,10 @@ class Manager {
 
 	public function resetAssignedSignalingServers(ICache $cache): void {
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->from('talk_rooms')
-			->where($query->expr()->isNotNull('assigned_hpb'));
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->where($query->expr()->isNotNull('r.assigned_hpb'));
 
 		$result = $query->execute();
 		while ($row = $result->fetch()) {
@@ -251,20 +267,20 @@ class Manager {
 	 */
 	public function searchRoomsByToken(string $searchToken = '', int $limit = null, int $offset = null): array {
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('id', 'r_id')
-			->from('talk_rooms')
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
 			->setMaxResults(1);
 
 		if ($searchToken !== '') {
-			$query->where($query->expr()->iLike('token', $query->createNamedParameter(
+			$query->where($query->expr()->iLike('r.token', $query->createNamedParameter(
 				'%' . $this->db->escapeLikeParameter($searchToken) . '%'
 			)));
 		}
 
 		$query->setMaxResults($limit)
 			->setFirstResult($offset)
-			->orderBy('token', 'ASC');
+			->orderBy('r.token', 'ASC');
 		$result = $query->execute();
 
 		$rooms = [];
@@ -288,13 +304,11 @@ class Manager {
 	 */
 	public function getRoomsForUser(string $userId, bool $includeLastMessage = false): array {
 		$query = $this->db->getQueryBuilder();
-		$query->select('r.*')
-			->addSelect('a.*')
-			->addSelect('s.*')
-			->selectAlias('r.id', 'r_id')
-			->selectAlias('a.id', 'a_id')
-			->selectAlias('s.id', 's_id')
-			->from('talk_rooms', 'r')
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_rooms', 'r')
 			->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
 				$query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)),
 				$query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)),
@@ -328,6 +342,81 @@ class Manager {
 		return $rooms;
 	}
 
+	/**
+	 * @param string $userId
+	 * @return string[]
+	 */
+	public function getRoomTokensForUser(string $userId): array {
+		$query = $this->db->getQueryBuilder();
+		$query->select('r.token')
+			->from('talk_attendees', 'a')
+			->leftJoin('a', 'talk_rooms', 'r', $query->expr()->eq('a.room_id', 'r.id'))
+			->where($query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)))
+			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)));
+
+		$result = $query->execute();
+		$roomTokens = [];
+		while ($row = $result->fetch()) {
+			if ($row['token'] === null) {
+				// FIXME Temporary solution for the Talk6 release
+				continue;
+			}
+
+			$roomTokens[] = $row['token'];
+		}
+		$result->closeCursor();
+
+		return $roomTokens;
+	}
+
+	/**
+	 * Returns rooms that are listable where the current user is not a participant.
+	 *
+	 * @param string $userId user id
+	 * @param string $term search term
+	 * @return Room[]
+	 */
+	public function getListedRoomsForUser(string $userId, string $term = ''): array {
+		$allowedRoomTypes = [Room::GROUP_CALL, Room::PUBLIC_CALL];
+		$allowedListedTypes = [Room::LISTABLE_ALL];
+		if (!$this->isGuestUser($userId)) {
+			$allowedListedTypes[] = Room::LISTABLE_USERS;
+		}
+		$query = $this->db->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
+				$query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)),
+				$query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)),
+				$query->expr()->eq('a.room_id', 'r.id')
+			))
+			->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
+				$query->expr()->eq('a.id', 's.attendee_id')
+			))
+			->where($query->expr()->isNull('a.id'))
+			->andWhere($query->expr()->in('r.type', $query->createNamedParameter($allowedRoomTypes, IQueryBuilder::PARAM_INT_ARRAY)))
+			->andWhere($query->expr()->in('r.listable', $query->createNamedParameter($allowedListedTypes, IQueryBuilder::PARAM_INT_ARRAY)));
+
+		if ($term !== '') {
+			$query->andWhere(
+				$query->expr()->iLike('name', $query->createNamedParameter(
+					'%' . $this->db->escapeLikeParameter($term). '%'
+				))
+			);
+		}
+
+		$result = $query->execute();
+		$rooms = [];
+		while ($row = $result->fetch()) {
+			$room = $this->createRoomObject($row);
+			$rooms[] = $room;
+		}
+		$result->closeCursor();
+
+		return $rooms;
+	}
+
 	/**
 	 * Does *not* return public rooms for participants that have not been invited
 	 *
@@ -338,18 +427,16 @@ class Manager {
 	 */
 	public function getRoomForUser(int $roomId, ?string $userId): Room {
 		$query = $this->db->getQueryBuilder();
-		$query->select('r.*')
-			->selectAlias('r.id', 'r_id')
-			->from('talk_rooms', 'r')
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
 			->where($query->expr()->eq('r.id', $query->createNamedParameter($roomId, IQueryBuilder::PARAM_INT)));
 
 		if ($userId !== null) {
 			// Non guest user
-			$query->addSelect('a.*')
-				->addSelect('s.*')
-				->selectAlias('a.id', 'a_id')
-				->selectAlias('s.id', 's_id')
-				->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
+			$helper->selectAttendeesTable($query);
+			$helper->selectSessionsTable($query);
+			$query->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
 					$query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)),
 					$query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)),
 					$query->expr()->eq('a.room_id', 'r.id')
@@ -386,30 +473,34 @@ class Manager {
 	}
 
 	/**
-	 * Also returns public rooms for participants that have not been invited,
-	 * so they can join.
+	 * Returns room object for a user by token.
+	 *
+	 * Also returns:
+	 * - public rooms for participants that have not been invited
+	 * - listable rooms for participants that have not been invited
+	 *
+	 * This is useful so they can join.
 	 *
 	 * @param string $token
 	 * @param string|null $userId
 	 * @param bool $includeLastMessage
+	 * @param bool $isSIPBridgeRequest
 	 * @return Room
 	 * @throws RoomNotFoundException
 	 */
-	public function getRoomForUserByToken(string $token, ?string $userId, bool $includeLastMessage = false): Room {
+	public function getRoomForUserByToken(string $token, ?string $userId, bool $includeLastMessage = false, bool $isSIPBridgeRequest = false): Room {
 		$query = $this->db->getQueryBuilder();
-		$query->select('r.*')
-			->selectAlias('r.id', 'r_id')
-			->from('talk_rooms', 'r')
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
 			->where($query->expr()->eq('r.token', $query->createNamedParameter($token)))
 			->setMaxResults(1);
 
 		if ($userId !== null) {
 			// Non guest user
-			$query->addSelect('a.*')
-				->addSelect('s.*')
-				->selectAlias('a.id', 'a_id')
-				->selectAlias('s.id', 's_id')
-				->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
+			$helper->selectAttendeesTable($query);
+			$helper->selectSessionsTable($query);
+			$query->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
 					$query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)),
 					$query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)),
 					$query->expr()->eq('a.room_id', 'r.id')
@@ -441,12 +532,21 @@ class Manager {
 			$room->setParticipant($row['actor_id'], $this->createParticipantObject($room, $row));
 		}
 
-		if ($room->getType() === Room::PUBLIC_CALL) {
+		if ($isSIPBridgeRequest || $room->getType() === Room::PUBLIC_CALL) {
 			return $room;
 		}
 
-		if ($userId !== null && $row['actor_id'] === $userId) {
-			return $room;
+		if ($userId !== null) {
+			// user already joined that room before
+			if ($row['actor_id'] === $userId) {
+				return $room;
+			}
+
+			// never joined before but found in listing
+			$listable = (int)$row['listable'];
+			if ($this->isRoomListableByUser($room, $userId)) {
+				return $room;
+			}
 		}
 
 		throw new RoomNotFoundException();
@@ -459,10 +559,10 @@ class Manager {
 	 */
 	public function getRoomById(int $roomId): Room {
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('id', 'r_id')
-			->from('talk_rooms')
-			->where($query->expr()->eq('id', $query->createNamedParameter($roomId, IQueryBuilder::PARAM_INT)));
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->where($query->expr()->eq('r.id', $query->createNamedParameter($roomId, IQueryBuilder::PARAM_INT)));
 
 		$result = $query->execute();
 		$row = $result->fetch();
@@ -489,13 +589,11 @@ class Manager {
 	 */
 	public function getRoomByActor(string $token, string $actorType, string $actorId): Room {
 		$query = $this->db->getQueryBuilder();
-		$query->select('r.*')
-			->addSelect('a.*')
-			->addSelect('s.*')
-			->selectAlias('a.id', 'a_id')
-			->selectAlias('s.id', 's_id')
-			->selectAlias('r.id', 'r_id')
-			->from('talk_rooms', 'r')
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_rooms', 'r')
 			->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
 				$query->expr()->eq('a.actor_type', $query->createNamedParameter($actorType)),
 				$query->expr()->eq('a.actor_id', $query->createNamedParameter($actorId)),
@@ -540,9 +638,9 @@ class Manager {
 		}
 
 		$query = $this->db->getQueryBuilder();
-		$query->select('r.*')
-			->selectAlias('r.id', 'r_id')
-			->from('talk_rooms', 'r')
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
 			->where($query->expr()->eq('r.token', $query->createNamedParameter($token)));
 
 		$result = $query->execute();
@@ -569,11 +667,11 @@ class Manager {
 	 */
 	public function getRoomByObject(string $objectType, string $objectId): Room {
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('id', 'r_id')
-			->from('talk_rooms')
-			->where($query->expr()->eq('object_type', $query->createNamedParameter($objectType)))
-			->andWhere($query->expr()->eq('object_id', $query->createNamedParameter($objectId)));
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->where($query->expr()->eq('r.object_type', $query->createNamedParameter($objectType)))
+			->andWhere($query->expr()->eq('r.object_id', $query->createNamedParameter($objectId)));
 
 		$result = $query->execute();
 		$row = $result->fetch();
@@ -603,11 +701,11 @@ class Manager {
 		}
 
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('r.id', 'r_id')
-			->selectAlias('a.id', 'a_id')
-			->selectAlias('s.id', 's_id')
-			->from('talk_sessions', 's')
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_sessions', 's')
 			->leftJoin('s', 'talk_attendees', 'a', $query->expr()->eq('a.id', 's.attendee_id'))
 			->leftJoin('a', 'talk_rooms', 'r', $query->expr()->eq('a.room_id', 'r.id'))
 			->where($query->expr()->eq('s.session_id', $query->createNamedParameter($sessionId)))
@@ -659,11 +757,11 @@ class Manager {
 		$name = json_encode($users);
 
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('id', 'r_id')
-			->from('talk_rooms')
-			->where($query->expr()->eq('type', $query->createNamedParameter(Room::ONE_TO_ONE_CALL, IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->eq('name', $query->createNamedParameter($name)));
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->where($query->expr()->eq('r.type', $query->createNamedParameter(Room::ONE_TO_ONE_CALL, IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->eq('r.name', $query->createNamedParameter($name)));
 
 		$result = $query->execute();
 		$row = $result->fetch();
@@ -689,11 +787,11 @@ class Manager {
 	 */
 	public function getChangelogRoom(string $userId): Room {
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('id', 'r_id')
-			->from('talk_rooms')
-			->where($query->expr()->eq('type', $query->createNamedParameter(Room::CHANGELOG_CONVERSATION, IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->eq('name', $query->createNamedParameter($userId)));
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->where($query->expr()->eq('r.type', $query->createNamedParameter(Room::CHANGELOG_CONVERSATION, IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->eq('r.name', $query->createNamedParameter($userId)));
 
 		$result = $query->execute();
 		$row = $result->fetch();
@@ -702,6 +800,7 @@ class Manager {
 		if ($row === false) {
 			$room = $this->createRoom(Room::CHANGELOG_CONVERSATION, $userId);
 			$room->setReadOnly(Room::READ_ONLY);
+			$room->setListable(Room::LISTABLE_NONE);
 
 			$this->participantService->addUsers($room,[[
 				'actorType' => Attendee::ACTOR_USERS,
@@ -808,21 +907,46 @@ class Manager {
 			return $otherParticipant;
 		}
 
-		try {
-			if ($userId === '') {
-				$sessionId = $this->talkSession->getSessionForRoom($room->getToken());
-				$room->getParticipantBySession($sessionId);
-			} else {
-				$room->getParticipant($userId);
+		if (!$this->isRoomListableByUser($room, $userId)) {
+			try {
+				if ($userId === '') {
+					$sessionId = $this->talkSession->getSessionForRoom($room->getToken());
+					$room->getParticipantBySession($sessionId);
+				} else {
+					$room->getParticipant($userId);
+				}
+			} catch (ParticipantNotFoundException $e) {
+				// Do not leak the name of rooms the user is not a part of
+				return $this->l->t('Private conversation');
 			}
-		} catch (ParticipantNotFoundException $e) {
-			// Do not leak the name of rooms the user is not a part of
-			return $this->l->t('Private conversation');
 		}
 
 		return $room->getName();
 	}
 
+	/**
+	 * Returns whether the given room is listable for the given user.
+	 *
+	 * @param Room $room room
+	 * @param string|null $userId user id
+	 */
+	public function isRoomListableByUser(Room $room, ?string $userId): bool {
+		if ($userId === null) {
+			// not listable for guest users with no account
+			return false;
+		}
+
+		if ($room->getListable() === Room::LISTABLE_ALL) {
+			return true;
+		}
+
+		if ($room->getListable() === Room::LISTABLE_USERS && !$this->isGuestUser($userId)) {
+			return true;
+		}
+
+		return false;
+	}
+
 	protected function getRoomNameByParticipants(Room $room): string {
 		$users = $this->participantService->getParticipantUserIds($room);
 		$displayNames = [];
@@ -852,9 +976,9 @@ class Manager {
 		}
 
 		$query = $this->db->getQueryBuilder();
-		$query->select('id')
-			->from('talk_rooms')
-			->where($query->expr()->eq('token', $query->createParameter('token')));
+		$query->select('r.id')
+			->from('talk_rooms', 'r')
+			->where($query->expr()->eq('r.token', $query->createParameter('token')));
 
 		$i = 0;
 		while ($i < 1000) {
@@ -920,6 +1044,21 @@ class Manager {
 		return $this->userManager->userExists($userId);
 	}
 
+	/**
+	 * Returns whether the given user id is a guest user from
+	 * the guest app
+	 *
+	 * @param string $userId user id to check
+	 * @return bool true if the user is a guest, false otherwise
+	 */
+	public function isGuestUser(string $userId): bool {
+		if (!$this->appManager->isEnabledForUser('guests')) {
+			return false;
+		}
+		// TODO: retrieve guest group name from app once exposed
+		return $this->groupManager->isInGroup($userId, 'guest_app');
+	}
+
 	protected function loadLastMessageInfo(IQueryBuilder $query): void {
 		$query->leftJoin('r','comments', 'c', $query->expr()->eq('r.last_message', 'c.id'));
 		$query->selectAlias('c.id', 'comment_id');
