@@ -33,6 +33,7 @@ use OCA\Talk\Manager;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
+use OCP\Comments\ICommentsManager;
 use OCP\Comments\NotFoundException;
 use OCP\IL10N;
 use OCP\IURLGenerator;
@@ -69,7 +70,7 @@ class Notifier implements INotifier {
 	protected $participantService;
 	/** @var INotificationManager */
 	protected $notificationManager;
-	/** @var CommentsManager */
+	/** @var ICommentsManager */
 	protected $commentManager;
 	/** @var MessageParser */
 	protected $messageParser;
@@ -568,7 +569,7 @@ class Notifier implements INotifier {
 			if ($user instanceof IUser) {
 				if ($this->notificationManager->isPreparingPushNotification() || $this->participantService->hasActiveSessionsInCall($room)) {
 					$notification = $this->addActionButton($notification, $l->t('Answer call'));
-					$subject = $l->t('{user} wants to talk with you');
+					$subject = $l->t('{user} would like to talk with you');
 				} else {
 					$notification = $this->addActionButton($notification, $l->t('Call back'));
 					$subject = $l->t('You missed a call from {user}');
